2. General Settings — Django Shop v0.0.0 documentation

### Navigation

- index
- previous |
- Django Shop v0.0.0 documentation »

# 2. General Settings

This is a small list of the settings defined in Django SHOP.

## 2.1. SHOP_PAYMENT_BACKENDS

A list (or iterable) of payment backend class pathes. These classes will be used as the active payment backends by the checkout system, and so anything in this list will be shown to the customer for him/her to make a decision

## 2.2. SHOP_SHIPPING_BACKENDS

In a similar fashion, this must be a list of Shipping backends. This list is used to display the end customer what shipping options are available to him/her during the checkout process.

## 2.3. SHOP_CART_MODIFIERS

Theses modifiers function like the django middlewares. The cart will call each of theses classes, in order, everytime it is displayed. They are passed every item in the cart, as well as the cart itself.

# 3. Backend specific Settings

Some backends define extra settings to tweak their behavior. This should be an exhaustive list of all of the backends and modifiers included in the trunk of django SHOP.

## 3.1. SHOP_SHIPPING_FLAT_RATE

The “flat rate” shipping module uses this to know how much to charge. This should be a string, and will be converted to a Decimal by the backend.

### Navigation

- index
- previous |
- Django Shop v0.0.0 documentation »